Name:           cxxtest
Version:        4.4
Release:        %mkrel 1
Summary:        A JUnit-like testing framework for C++

Group:          Development/C++
License:        LGPLv2+
URL:            http://cxxtest.com/
Source0:        https://sourceforge.net/projects/cxxtest/files/cxxtest/%{version}/%{name}-%{version}.tar.gz

# Documentation
Source1:        http://cxxtest.com/guide.pdf

Patch0:         %{name}-shebang.patch

BuildArch:      noarch
BuildRequires:  asciidoc >= 8.5.0
BuildRequires:  python3-devel

# the --fog-parser option requires 'ply'
Requires:       python3-ply

%description
CxxTest is a JUnit/CppUnit/xUnit-like framework for C++.
Its advantages over existing alternatives are that it:
 - doesn't require RTTI
 - doesn't require member template functions
 - doesn't require exception handling
 - doesn't require any external libraries (including memory management,
   file/console I/O, graphics libraries)

%files
%doc COPYING README Versions
%{_bindir}/cxxtestgen.py
%{_bindir}/cxxtestgen
%{_includedir}/cxxtest/
%{_datadir}/pkgconfig/%{name}.pc
%{_mandir}/man1/cxxtestgen.1.*
%{python3_sitelib}/%{name}/
%{python3_sitelib}/%{name}-*.egg-info

#--------------------------------------------------------------------

%package doc
Summary:        Documentation on how to use CxxTest
Group:          Documentation

%description doc
This package contains the documentation on how to use CxxTest.

%files doc
%doc guide.pdf doc/images/

#--------------------------------------------------------------------

%prep
%setup -q
%patch0 -p1
cp -a %{SOURCE1} .
find . -name ".cvsignore" -delete

%build
cd python
%py3_build

# create pkgconfig file
cd ..
cat <<EOF >%{name}.pc
prefix=%{_prefix}
exec_prefix=%{_prefix}
includedir=%{_includedir}/%{name}

Name: %{name}
Description: A JUnit-like testing framework for C++
Version: %{version}
Cflags: -I\${includedir}
EOF

cd doc

# script to create asciidoc file for manpage of cxxtestgen
cat <<EOF >create_manpage.py
import sys
sys.path.insert(0, '../python/python3')
import cxxtest
cxxtest.create_manpage()
EOF

# create manpage
%{__python3} create_manpage.py
a2x -f manpage cxxtestgen.1.txt

%install
mkdir -p %{buildroot}%{_includedir}/cxxtest
install -D -p -m 644 cxxtest/* %{buildroot}%{_includedir}/cxxtest
install -D -p -m 644 %{name}.pc %{buildroot}%{_datadir}/pkgconfig/%{name}.pc

cd python
%py3_install

# add symlink present in previous release of cxxtest
ln -s %{_bindir}/cxxtestgen %{buildroot}%{_bindir}/cxxtestgen.py

cd ..
install -D -p -m 644 doc/cxxtestgen.1 %{buildroot}%{_mandir}/man1/cxxtestgen.1


%changelog
* Thu Feb 13 2020 daviddavid <daviddavid> 4.4-1.mga8
+ Revision: 1513951
- new version: 4.4
- update URL and Source URL
- fix python shebangs
- add a pkgconfig file
- build a manpage
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Tue Sep 18 2018 umeabot <umeabot> 3.10.1-8.mga7
+ Revision: 1262084
- Mageia 7 Mass Rebuild

* Thu Feb 04 2016 umeabot <umeabot> 3.10.1-7.mga6
+ Revision: 935925
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 3.10.1-6.mga5
+ Revision: 743638
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 3.10.1-5.mga5
+ Revision: 678657
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 3.10.1-4.mga4
+ Revision: 503772
- Mageia 4 Mass Rebuild

* Fri Jan 11 2013 umeabot <umeabot> 3.10.1-3.mga3
+ Revision: 348529
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Nov 09 2012 fwang <fwang> 3.10.1-2.mga3
+ Revision: 316602
- update rpm group

* Thu Jul 26 2012 neoclust <neoclust> 3.10.1-1.mga3
+ Revision: 274663
- imported package cxxtest


* Wed Jul 18 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.10.1-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.10.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Mon Dec 19 2011 Martin Gieseking <martin.gieseking@uos.de> - 3.10.1-5
- Fixed https://bugzilla.redhat.com/show_bug.cgi?id=768869

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.10.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Wed Aug 05 2009 Martin Gieseking <martin.gieseking@uos.de> - 3.10.1-3
- added exclude tags in files section

* Tue Aug 04 2009 Martin Gieseking <martin.gieseking@uos.de> - 3.10.1-2
- moved headers from devel to main package
- added BuildRequires to avoid build problems
- dropped Requires tag
- cxxtest include directory now explicitely listed in files section

* Tue Aug 04 2009 Martin Gieseking <martin.gieseking@uos.de> - 3.10.1-1
- initial release
